==> mobGameSDK-4.1.6-sources.jar: com/mobgame/api/GetInfoAfterAuthenTask.java <==
package com.mobgame.api;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.mobgame.MobGameSDK;
import com.mobgame.component.GameConfigManager;
import com.mobgame.model.EncodedResponse;
import com.mobgame.model.Game;
import com.mobgame.model.MobPopup;
import com.mobgame.model.MobMenu;
import com.mobgame.model.NtfModel;
import com.mobgame.model.TimerData;
import com.mobgame.model.UserInfo;
import com.mobgame.utils.Constants;
import com.mobgame.utils.EncryptionUtils;
import com.mobgame.utils.FunTrackingUtil;
import com.mobgame.utils.NotificationUtils;
import com.mobgame.utils.Preference;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class GetInfoAfterAuthenTask extends AsyncTask<Void, Void, Void> {

    private static final String TAG = GetInfoAfterAuthenTask.class.getName();
    private Listener callback;

    public GetInfoAfterAuthenTask(Listener callback) {
        this.callback = callback;
    }

    @Override
    protected Void doInBackground(Void... params) {
        Context c = MobGameSDK.getApplicationContext();
        String sign = EncryptionUtils.getSignedString(c);
        RestfulApi.removeInstance();
        RestfulApi api = RestfulApi.getInstance();
        Call<EncodedResponse> call = api.getInfoAfterAuthen(sign);
        call.enqueue(new Callback<EncodedResponse>() {

            @Override
            public void onResponse(Call<EncodedResponse> call, Response<EncodedResponse> response) {

                try {
                    Context c = MobGameSDK.getApplicationContext();
                    UserInfo userInfo = null;
                    Log.d("TAG", "code : " + response.code());
                    if (response.code() == 200 && response.body() != null) {

                        String responseBody = response.body().getDecodedData();
                        try {
                            JSONObject json = new JSONObject(responseBody);
                            Log.d(TAG, "onResponse: " + json);
                            if (json.has("saveLogin")) {
                                String saveLogin = json.getString("saveLogin");

                                if (saveLogin.equals("true") || saveLogin.equals("1")) {

                                    if (json.has("userInfo")) {
                                        String userInfoStr = json.getString("userInfo");
                                        userInfo = UserInfo.parse(userInfoStr);
                                    }

                                    if (json.has("ntf")) {
                                        String ntf = json.getString("ntf");
                                        JSONArray ntfs = new JSONArray(ntf);
                                        ArrayList<NtfModel> listNtfs = new ArrayList<NtfModel>();
                                        for (int i = 0; i < ntfs.length(); i++) {
                                            JSONObject ntfObj = ntfs.getJSONObject(i);
                                            if (ntfObj.has("id") && ntfObj.has("noti")
                                                    && ntfObj.getBoolean("noti")) {
                                                NtfModel ntfModel = new NtfModel();
                                                ntfModel.setId(ntfObj.getInt("id"));
                                                ntfModel.setTitle(ntfObj.getString("title"));
                                                ntfModel.setNoti(ntfObj.getBoolean("noti"));
                                                listNtfs.add(ntfModel);

                                                NotificationUtils.addNtf(c, ntfModel);
                                                GameConfigManager.getInstance().setHasUnreadNotifications(true);
                                            }
                                        }
                                        listNtfs = NotificationUtils.getNtfs(c);
                                        if(listNtfs.size() > 0) {
                                            GameConfigManager.getInstance().setHasUnreadNotifications(true);
                                        }
                                        NotificationUtils.setListNtfFromAfterAuth(listNtfs);
                                    }

                                    if (json.has("menu")) {
                                        String menu = json.getString("menu");
                                        MobMenu mobMenu = MobMenu.parse(menu);
                                        GameConfigManager.getInstance().setMobMenu(mobMenu);
                                    } else {
                                        GameConfigManager.getInstance().clearMobMenu();
                                    }

                                    if (json.has("enable_dashboard")) {
                                        boolean value = json.getBoolean("enable_dashboard");
                                        Preference.save(c,
                                                Constants.SHARED_PREF_DB_ENABLED,
                                                value);
                                    } else {
                                        Preference.remove(c, Constants.SHARED_PREF_DB_ENABLED);
                                    }

                                    if (json.has("show_qc")) {
                                        boolean showAds = (json.getInt("show_qc") != 0);
                                        Preference.save(c,
                                                Constants.SHARED_PREF_SHOW_ADS,
                                                showAds);
                                        GameConfigManager.getInstance().setShow_qc(showAds);
                                    } else {
                                        Preference.remove(c, Constants.SHARED_PREF_SHOW_ADS);
                                    }

                                    if (json.has("level_show_ads")){
                                        String showLevelAds = json.getString("level_show_ads");
                                        GameConfigManager.getInstance().setLevelShowAds(showLevelAds);
                                        Log.d("level_show_ads", "level_show_ads : " + showLevelAds);
                                    }

                                    if (json.has("enable_timer")) {
                                        boolean enableTimer = json.optBoolean("enable_timer");
                                        userInfo.setEnableTimer(enableTimer);
                                        if (enableTimer) {
                                            TimerData timerData = TimerData.parse(json.optJSONArray("timer"));
                                            userInfo.setTimerData(timerData);
                                        }
                                    }
                                    if (json.has("pop")) {
                                        try {
                                            JSONObject pop = json.getJSONObject("pop");
                                            boolean is_show_link = pop.getBoolean("is_show");
                                            String link = pop.getString("link");
                                            Log.d(TAG, "is_show: " + is_show_link);
                                            Log.d(TAG, "link: " + link);
                                            MobPopup mobPopup = new MobPopup(link, is_show_link);
                                            GameConfigManager.getInstance().setMobPopup(mobPopup);
                                        } catch (Exception e) {
                                            e.printStackTrace();
                                            MobPopup mobPopup = new MobPopup("", false);
                                            GameConfigManager.getInstance().setMobPopup(mobPopup);
                                        }
                                    }
                                    if (json.has("timer")) {

                                    }
                                    if (json.has("error_link")) {

                                    }
                                }
                            }
                        } catch (JSONException e) {
                            if (callback != null) {
                                callback.onFailure(e);
                            }
                        }

                        if (callback != null) {
                            callback.onSuccess(userInfo);
                        }

                    } else if(response.code() == 403 && response.body() != null) {
                        if(callback != null){
                            callback.forceLogout();
                        }
                    } else {
                        if (callback != null) {
                            Log.d(TAG, "ERROR when " + response.code());
                            callback.onFailure(new Exception());
                        }
                    }
                } catch (Exception e) {
                    if (callback != null) {
                        callback.onFailure(e);
                    }
                    e.printStackTrace();
                }
            }

            @Override
            public void onFailure(Call<EncodedResponse> call, Throwable t) {
                if (callback != null) {
                    callback.onFailure(t);
                }
            }
        });
        return null;
    }

    public interface Listener {
        public void onSuccess(UserInfo userInfo);
        public void forceLogout();
        public void onFailure(Throwable t);
    }

}

==> mobGameSDK-4.2.2-sources.jar: com/mobgame/api/GetInfoAfterAuthenTask.java <==
package com.mobgame.api;

import android.content.Context;
import android.os.AsyncTask;
import android.support.annotation.NonNull;
import android.util.Log;

import com.mobgame.MobGameSDK;
import com.mobgame.component.GameConfigManager;
import com.mobgame.model.EncodedResponse;
import com.mobgame.model.Game;
import com.mobgame.model.MobPopup;
import com.mobgame.model.MobMenu;
import com.mobgame.model.NtfModel;
import com.mobgame.model.TimerData;
import com.mobgame.model.UserInfo;
import com.mobgame.utils.Constants;
import com.mobgame.utils.EncryptionUtils;
import com.mobgame.utils.FunTrackingUtil;
import com.mobgame.utils.NotificationUtils;
import com.mobgame.utils.Preference;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Objects;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class GetInfoAfterAuthenTask extends AsyncTask<Void, Void, Void> {

    private static final String TAG = GetInfoAfterAuthenTask.class.getName();
    private Listener callback;

    public GetInfoAfterAuthenTask(Listener callback) {
        this.callback = callback;
    }

    @Override
    protected Void doInBackground(Void... params) {
        Context c = MobGameSDK.getApplicationContext();
        String sign = EncryptionUtils.getSignedString(c);
        RestfulApi.removeInstance();
        RestfulApi api = RestfulApi.getInstance();
        Call<EncodedResponse> call = api.getInfoAfterAuthen(sign);
        call.enqueue(new Callback<EncodedResponse>() {

            @Override
            public void onResponse(@NonNull Call<EncodedResponse> call, @NonNull Response<EncodedResponse> response) {

                try {
                    Context c = MobGameSDK.getApplicationContext();
                    UserInfo userInfo = null;
                    Log.d("TAG", "code : " + response.code());
                    if (response.code() == 200 && response.body() != null) {

                        String responseBody = response.body().getDecodedData();
                        try {
                            JSONObject json = new JSONObject(responseBody);
                            Log.d(TAG, "onResponse: " + json);
                            if (json.has("saveLogin")) {
                                String saveLogin = json.getString("saveLogin");

                                if (saveLogin.equals("true") || saveLogin.equals("1")) {

                                    if (json.has("userInfo")) {
                                        String userInfoStr = json.getString("userInfo");
                                        userInfo = UserInfo.parse(userInfoStr);
                                    }

                                    if (json.has("ntf")) {
                                        String ntf = json.getString("ntf");
                                        JSONArray ntfs = new JSONArray(ntf);
                                        ArrayList<NtfModel> listNtfs = new ArrayList<NtfModel>();
                                        for (int i = 0; i < ntfs.length(); i++) {
                                            JSONObject ntfObj = ntfs.getJSONObject(i);
                                            if (ntfObj.has("id") && ntfObj.has("noti")
                                                    && ntfObj.getBoolean("noti")) {
                                                NtfModel ntfModel = new NtfModel();
                                                ntfModel.setId(ntfObj.getInt("id"));
                                                ntfModel.setTitle(ntfObj.getString("title"));
                                                ntfModel.setNoti(ntfObj.getBoolean("noti"));
                                                listNtfs.add(ntfModel);

                                                NotificationUtils.addNtf(c, ntfModel);
                                                GameConfigManager.getInstance().setHasUnreadNotifications(true);
                                            }
                                        }
                                        listNtfs = NotificationUtils.getNtfs(c);
                                        if(listNtfs.size() > 0) {
                                            GameConfigManager.getInstance().setHasUnreadNotifications(true);
                                        }
                                        NotificationUtils.setListNtfFromAfterAuth(listNtfs);
                                    }

                                    if (json.has("menu")) {
                                        String menu = json.getString("menu");
                                        MobMenu mobMenu = MobMenu.parse(menu);
                                        GameConfigManager.getInstance().setMobMenu(mobMenu);
                                    } else {
                                        GameConfigManager.getInstance().clearMobMenu();
                                    }

                                    if (json.has("enable_dashboard")) {
                                        boolean value = json.getBoolean("enable_dashboard");
                                        Preference.save(c,
                                                Constants.SHARED_PREF_DB_ENABLED,
                                                value);
                                    } else {
                                        Preference.remove(c, Constants.SHARED_PREF_DB_ENABLED);
                                    }

                                    if (json.has("show_qc")) {
                                        boolean showAds = (json.getInt("show_qc") != 0);
                                        Preference.save(c,
                                                Constants.SHARED_PREF_SHOW_ADS,
                                                showAds);
                                        GameConfigManager.getInstance().setShow_qc(showAds);
                                    } else {
                                        Preference.remove(c, Constants.SHARED_PREF_SHOW_ADS);
                                    }

                                    if (json.has("level_show_ads")){
                                        String showLevelAds = json.getString("level_show_ads");
                                        GameConfigManager.getInstance().setLevelShowAds(showLevelAds);
                                        Log.d("level_show_ads", "level_show_ads : " + showLevelAds);
                                    }

                                    if (json.has("enable_timer")) {
                                        boolean enableTimer = json.optBoolean("enable_timer");
                                        Objects.requireNonNull(userInfo).setEnableTimer(enableTimer);
                                        if (enableTimer) {
                                            TimerData timerData = TimerData.parse(json.optJSONArray("timer"));
                                            userInfo.setTimerData(timerData);
                                        }
                                    }
                                    if (json.has("pop")) {
                                        try {
                                            JSONObject pop = json.getJSONObject("pop");
                                            boolean is_show_link = pop.getBoolean("is_show");
                                            String link = pop.getString("link");
                                            Log.d(TAG, "is_show: " + is_show_link);
                                            Log.d(TAG, "link: " + link);
                                            MobPopup mobPopup = new MobPopup(link, is_show_link);
                                            GameConfigManager.getInstance().setMobPopup(mobPopup);
                                        } catch (Exception e) {
                                            e.printStackTrace();
                                            MobPopup mobPopup = new MobPopup("", false);
                                            GameConfigManager.getInstance().setMobPopup(mobPopup);
                                        }
                                    }
                                    if (json.has("timer")) {

                                    }
                                    if (json.has("error_link")) {

                                    }
                                }
                            }
                        } catch (JSONException e) {
                            if (callback != null) {
                                callback.onFailure(e);
                            }
                        }

                        if (callback != null) {
                            callback.onSuccess(userInfo);
                        }

                    } else if(response.code() == 403 && response.body() != null) {
                        if(callback != null){
                            callback.forceLogout();
                        }
                    } else {
                        if (callback != null) {
                            Log.d(TAG, "ERROR when " + response.code());
                            callback.onFailure(new Exception());
                        }
                    }
                } catch (Exception e) {
                    if (callback != null) {
                        callback.onFailure(e);
                    }
                    e.printStackTrace();
                }
            }

            @Override
            public void onFailure(@NonNull Call<EncodedResponse> call, @NonNull Throwable t) {
                if (callback != null) {
                    callback.onFailure(t);
                }
            }
        });
        return null;
    }

    public interface Listener {
        public void onSuccess(UserInfo userInfo);
        public void forceLogout();
        public void onFailure(Throwable t);
    }

}
